travis_log_fetch
================

A command line tool to fetch logs from Travis-CI.

Documentation
-------------

Please visit the `GitHub page`_ for documentation.


.. _GitHub page: https://github.com/jayvdb/travis_log_fetch

